@@ -1,6 +1,5 @@
 #include <config.h>
-#define WNCK_I_KNOW_THIS_IS_UNSTABLE
-#include <libwnck/libwnck.h>
+#include <libmatewnck/libmatewnck.h>
 #include <dirent.h>
 #include <sys/stat.h>
 #include <stdio.h>
@@ -24,7 +23,7 @@ namespace
 
 PrettyTable::PrettyTable()
 {
-  WnckScreen* screen = wnck_screen_get_default();
+  MatewnckScreen* screen = matewnck_screen_get_default();
   g_signal_connect(G_OBJECT(screen), "application_opened",
 		   G_CALLBACK(PrettyTable::on_application_opened), this);
   g_signal_connect(G_OBJECT(screen), "application_closed",
@@ -38,16 +37,16 @@ PrettyTable::~PrettyTable()
 
 
 void
-PrettyTable::on_application_opened(WnckScreen* screen, WnckApplication* app, gpointer data)
+PrettyTable::on_application_opened(MatewnckScreen* screen, MatewnckApplication* app, gpointer data)
 {
   PrettyTable * const that = static_cast<PrettyTable*>(data);
 
-  pid_t pid = wnck_application_get_pid(app);
+  pid_t pid = matewnck_application_get_pid(app);
 
   if (pid == 0)
     return;
 
-  const char* icon_name = wnck_application_get_icon_name(app);
+  const char* icon_name = matewnck_application_get_icon_name(app);
 
 
   Glib::RefPtr<Gdk::Pixbuf> icon;
@@ -55,7 +54,7 @@ PrettyTable::on_application_opened(WnckScreen* screen, WnckApplication* app, gpo
   icon = that->theme->load_icon(icon_name, APP_ICON_SIZE, Gtk::ICON_LOOKUP_USE_BUILTIN);
 
   if (not icon) {
-    icon = Glib::wrap(wnck_application_get_icon(app), /* take_copy */ true);
+    icon = Glib::wrap(matewnck_application_get_icon(app), /* take_copy */ true);
     icon = icon->scale_simple(APP_ICON_SIZE, APP_ICON_SIZE, Gdk::INTERP_HYPER);
   }
 
@@ -77,16 +76,16 @@ PrettyTable::register_application(pid_t pid, Glib::RefPtr<Gdk::Pixbuf> icon)
       info->set_icon(icon);
       // move the ref to the map
       this->apps[pid] = icon;
-      procman_debug("WNCK OK for %u", unsigned(pid));
+      procman_debug("MATEWNCK OK for %u", unsigned(pid));
     }
 }
 
 
 
 void
-PrettyTable::on_application_closed(WnckScreen* screen, WnckApplication* app, gpointer data)
+PrettyTable::on_application_closed(MatewnckScreen* screen, MatewnckApplication* app, gpointer data)
 {
-  pid_t pid = wnck_application_get_pid(app);
+  pid_t pid = matewnck_application_get_pid(app);
 
   if (pid == 0)
     return;
@@ -156,7 +155,7 @@ PrettyTable::get_icon_from_default(const ProcInfo &info)
 
 
 Glib::RefPtr<Gdk::Pixbuf>
-PrettyTable::get_icon_from_wnck(const ProcInfo &info)
+PrettyTable::get_icon_from_matewnck(const ProcInfo &info)
 {
   Glib::RefPtr<Gdk::Pixbuf> icon;
 
@@ -223,7 +222,7 @@ PrettyTable::set_icon(ProcInfo &info)
 
   if (getters.empty())
     {
-      getters.push_back(&PrettyTable::get_icon_from_wnck);
+      getters.push_back(&PrettyTable::get_icon_from_matewnck);
       getters.push_back(&PrettyTable::get_icon_from_theme);
       getters.push_back(&PrettyTable::get_icon_from_default);
       getters.push_back(&PrettyTable::get_icon_from_name);
